# Changelog

## [Unreleased]

## [0.1.0] - 2024-02-02

- Adds Secrets CLI
- Adds Application management CLI
- Adds `--org` to configure the organization in every grpc request
- Adds Artifacts and Triggers (`unionai.artifacts`)
